---
layout: post
title: "The State of the Zcash Foundation in 2019"
excerpt: "An explanation of the Zcash Foundation’s plans and finances in 2019."
categories: blog
tags: []
image:
  feature: 
date: 2019-01-31
author: acityinohio
---

Last year after becoming the Zcash Foundation's Executive Director, I prescribed a [roadmap for 2018](/blog/exec-director-and-roadmap/) and suggested how we could evaluate our efforts. In this post I'll reflect on the Foundation’s progress, provide an update on our finances, set a course for 2019, and pose some open questions for the community.

## How We Did in 2018 

The Zcash Foundation exists [to serve its mission](https://www.zfnd.org/about/#mission) of building and supporting privacy infrastructure for the public good, primarily serving users of the Zcash protocol and blockchain. Our activities spanned the three themes of community, science, and governance. In last year's [roadmap post](/blog/exec-director-and-roadmap/) I specified a number of tactical steps and metrics under each category. So, how did we do?

### Community

Our community efforts were relatively successful. The highest priority was Zcon0, which on all of our metrics — full attendance, positive sentiment and feedback — [was a success](/blog/zcon0-recap/).

We've grown our direct reach in the community in various ways online: Staff are more active on the Zcash Community Forum, Twitter, GitHub, mailing lists, and the like. We created [a meetups guide](https://www.zfnd.org/meetups/) and hosted and co-sponsored several events.

We also transferred the community-run chat and previously-Zcash-Company-run forum to Foundation stewardship. We directly [funded wallet infrastructure](https://www.zfnd.org/blog/wallet-agreements/), some of which is available today.

Some metrics proved less relevant or were not directly related to our efforts, although they may have improved. For example, use of shielded transactions did increase in the last year, but it's hard to ascribe that to Foundation efforts. Perhaps some combination of Sapling activation and more wallet support from the Foundation led to increased shielded TX volume?

Two metrics we could improve on next year: More educational resources about zk-SNARKs and privacy tech on the website, and more casual, small-scale grants. The [website redesign](https://www.zfnd.org/blog/website-refresh/) was the first step toward the former, and we're working on building a new community-funding mechanism for the latter. Development is ongoing.

### Science

Our scientific endeavors were a mixed bag. On the plus side, we began a [partnership with Parity](https://www.zfnd.org/blog/parity-partnership/) to develop a Rust implementation for Zcash, we successfully funded another [$264k of grants](https://www.zfnd.org/blog/q2-grant-winners/), and Zcon0 enabled a great deal of collaboration across researchers.

But we missed the mark in a number of ways. We didn't fund security audits for Sapling ([something that was done independently by the Company](https://electriccoin.co/blog/2018-security-audit-results-overview/)), we didn't fund other privacy-protocol devs (we tried some outreach during the grant program but it didn't go anywhere), we stalled out on technical hiring, and perhaps the worst failure: Our 2018Q2 Grant Program was so delayed that we shelved the 2018Q4 Grant Program in order to reevaluate the process.

We can do better, and already we're off to a good start this year. The Foundation is making our first, very critical technical hire (more news on that very soon) and we are working with another group to build a Monero FFS-inspired community funding mechanism to streamline our too-rigid grant program — something that's been on our radar [for a while](https://twitter.com/acityinohio/status/1009292320104177664).

### Governance

Honestly, this is the hardest to measure. On the one hand, we considered our [community governance process](https://www.zfnd.org/blog/governance-results/) to be a pretty successful experiment. It materially affected Foundation policies, leading to two new Board members and direct changes in policy. The process surfaced a number of great candidates for the Board, as openly as we could imagine. (Of the 74 community members that applied to participate, only two were rejected.)

So what's the other hand? The other hand is the Zcash Company, which wasn't affected by this process at all. Granted, it’s a separate entity outside of Foundation control, but that doesn't change the fundamental critique: What's the point of a governance process if it doesn't have any say in protocol decisions? Of course there is much that _shouldn't_ be decided by these processes; I wouldn't put zk-SNARK circuit design up for a vote by committee, for example. But suffice to say the Foundation — and by extension, the community — should have a seat at the table.

How? A new ZIP process should include more Foundation input, and we are progressing toward a trademark agreement with the Company. I'm hopeful that we can expand our governance process to include new mechanisms for polling users in the community, including as many demographics and populations as possible, from users to traders to miners and more.

Ultimately, the most realpolitik expression of influence is _the software users run, and the process by which they agree to run said software_. The Company squarely holds a monopoly here, but with the Parity agreement, our own wallet initiatives, and broadening the ZIP process, I believe we can materially change the power distribution. The more distributed, the better for the long-term sustainability of Zcash.

## The Foundation's Mission in 2019...

...is unchanged. We are still dedicated to supporting internet payment and privacy infrastructure for the public good, primarily through the Zcash protocol. We will continue our focus on the pillars of community, science, and governance. The goals we had in 2017 and 2018 are the same goals we have for 2019, but with a renewed energy toward _redistributing centers of unilateral power in the Zcash ecosystem_, mirroring some of the lessons above and reflected in [my sentiments at Devcon4](https://www.youtube.com/watch?v=Bl8qdiJQ4Tc). Rather than split up metrics by category, I suggest keeping an eye on the Foundation's progress on these tactical to-dos:

- A successful Zcon1!
- Launching mobile and desktop reference wallets, with non-trivial usage (>10% of users, not sure how to measure)
- Launching Parity Zcash with non-trivial node counts (>10% of reachable nodes)
- Reach a nontrivial number of contributors to Parity Zcash (5-10 contributors, might not happen this year, but worth noting)
- Reach trademark agreement with Company that emulates 2-of-2 multisig for trademark enforcement
- Launch new grant platform and distribute $250k in grants
- Build new ZIP process that compliments the Zcash Company's Network Upgrade Pipeline but ensures external validation and debate
- Nontrivial number of community-led ZIPs (3-5+)
- Launch resource hub for privacy and Zcash on the Foundation website
- Expand upon governance experiment with new methods for feedback (shielded plus staked votes as a starter)
- Make contributions to more speculative cryptographic research (either through grants, contracts, or direct work from Foundation employees)

<h2 id="finances">The Foundation's Finances, Today and Tomorrow</h2>

How will we fund the above? This question remains on the [forefront of the community's mind](https://forum.zcashcommunity.com/t/zcash-foundation-board-of-directors/32583), and it's one I hope to answer with clarity in this section.

### Original and Modified 2018 Budget

The original budget the [Board approved for 2018](https://www.zfnd.org/blog/exec-director-and-roadmap/) outlined plans to spend **$1.3mm**, including $250k for Grants, $357k for Zcon0, and $430k for wages. In [mid-June](https://www.zfnd.org/about/board-minutes/#june-22-2018) the Board voted to add research funding and double the wage expense to expand our hiring. Including this adjustment, our new guidelines for 2018 included **2.4mm** of spending, including $250k for Grants, $357k for Zcon0, and $873k for wage expense.

### Actual Spend vs Budget

|           | Budgeted   | Actual    |
|-----------|------------|-----------|
| **Total** | **$2.4mm** | **$935k** | 
| Zcon0     | $357k      | $363k     |
| Grants    | $250k      | $139k     |
| Wages     | $873k      | $312k     |
| Other     | $920k      | $121k     |

It’s readily apparent that we under-spent compared to our budget guidelines. More details:

* Zcon0: Slightly more expensive than expected, but mitigated somewhat with ticket revenue.
* Grants: We disbursed $250k+ of grants, but the actual spend for us was $125k cheaper thanks to a generous donation by the [Research Institute (previously known as the Blockchain Institute](https://researchinstitute.io/).
* Wages: We really wanted to expand headcount, but hiring in the cryptocurrency industry is hard (particularly for a nonprofit that can't offer early equity). On the flip side, I have a preference for slower hiring; since we're not a startup we can be more methodical here.
* Other spending: Mostly administrative costs, legal, travel, event sponsorships, with a few research contracts thrown in. (e.g., mobile wallet development with X Wallet, zec-qt-wallet, etc.) The large gap here stems from many research contracts that were in the process of being negotiated but weren't signed before the end of 2018.

### Budget for 2019

[At its last meeting](https://www.zfnd.org/about/board-minutes/#november-15-2018) the Board approved a new budget that I proposed, with more aggressive spending goals. A more detailed look here:

|           |             |
|-----------|-------------|
| **Total** | **$3.14mm** |
| Zcon1     | $389k       |
| Grants    | $500k       |
| Wages     | $1.17mm     |
| Research  | $665k       | 
| Other     | $387k       |

* Zcon1: We reduced the ticket price to $500, but thanks to a cheaper location and lessons learned from last year, it isn't likely to be a net increase in cost.
* Grants: In concert with the new grants platform, we want to both increase grant spend and become more efficient at judging potential grants.
* Wages: As I’ve mentioned, hiring was slower than expected last year. But we have momentum on that front! The Foundation has three full-time employees, but you'll hear about a fourth soon. 😉 We to hope to expand headcount by an additional two or three technical hires this year.
* Research: This category wasn't highlighted in 2018, but it's prominent enough to highlight it now. Agreements with contractors that involve more direct Foundation involvement, like our partnerships with zec-qt-wallet and Parity, go under this category. We expect a few more major research contractor agreements this year.
* Other: Sponsorships, travel, legal costs, Foundation admin, etc. fall under this category.

### Current ZEC, BTC, and USD Holdings

To round out this summary of the Foundation's finances, let's cover our treasury. At the time of this writing, the Foundation has been pledged roughly 260,000 ZEC, mostly from recipients of the Founders' Reward. To date we have received 87,000 ZEC of this pledge, and spent roughly 30,000 ZEC — either in ZEC-to-USD trades to fund day-to-day operations or in direct sends. Here is our cash on-hand and other assets: 

| Asset        | Amount   |
|--------------|----------|
| BTC          | 7.8      | 
| Current ZEC  | 57k      |
| USD          | $4.6mm   |
| Expected ZEC | 173k     |

At a price of $50 USD per ZEC, we have roughly $16 million in assets, which translates to a five-year runway if we meet the 2019 expected budget. Obviously swings in ZEC price could materially change this calculation.

## Considering the State of the Foundation (and Zcash Ecosystem)

In the short-to-medium term I am not concerned about the Foundation's finances or ability to execute. Antonie and Sonya (my colleagues) have done wonderful work, as have the many grant recipients and contractors that work with us. No doubt, we have areas to improve, but I'm thrilled with the progress the Zcash Foundation has made in 2018 and excited for 2019.

Longer term, we need to start thinking about how the Foundation can sustainably operate with donations in addition to its endowment, which will entail a concerted effort to solicit donations from the community in the future.

Looking beyond the Foundation, I think it's critical to reflect on where power — and expertise — sits in the Zcash ecosystem today. As I’ve said above, the central issue that faces our community today is centralization of power in the Company. But it’s a necessary centralization… for now. The Company employs many of the world’s top experts in zero-knowledge systems, and their contributions are critical to the development of the protocol.

If the Company were to disappear today, that would be a tragedy for the ecosystem. It would set us back by years if not decades. And that's a fundamental problem for a protocol that's meant to be robust as currency, that's meant to protect privacy and adapt to the unforeseen privacy challenges of tomorrow. For the Foundation — and the ecosystem at large — it's imperative that we encourage Company contributions to Zcash while paradoxically (and amicably) reducing their burden as stewards of the protocol.

