---
layout: table
title: Zcash Trademark Policy
excerpt: "How you can and cannot use the Zcash trademark."
---

Last updated: November 18, 2019.

## Introduction

This document, the "Policy," outlines the Zcash Foundation's (the "Foundation") policy for the use of the Zcash trademarks. While the Zcash software is available under a free and open source software license, the copyright license does not include an implied right or license to use the Zcash trademarks.

The role of trademarks is to provide assurance about the quality of the products or services with which the trademark is associated. But because an open source license allows your unrestricted modification of the copyrighted software, we cannot be sure that your modifications to the software are ones that will not be misleading if distributed under the same name. Instead, this Policy describes the circumstances under which you may use our trademarks.

In this Policy we are not trying to limit the lawful use of our trademarks, but rather describe for you what we consider the parameters of lawful use to be. Trademark law can be ambiguous, so we hope to provide enough clarity for you to understand whether we will consider your use licensed or non-infringing.

This Trademark Policy attempts to balance two competing interests: Our need to ensure that the Zcash Trademarks remain reliable indicators of quality, source, and security; and our desire to permit community members, Zcash users, software distributors, service providers, and others with whom Foundation works to discuss Zcash and to accurately describe their affiliation with us. Striking a proper balance is a tricky situation that many organizations—in particular those whose products are distributed electronically—wrestle with every day and we’ve attempted to balance it here.

The sections that follow describe what trademarks are covered by this Policy, as well as uses of the trademarks that are allowed without additional permission from us. If you want to use our trademarks in ways that are not described in this Policy, please see "For further information" below for contact information. Any use that does not comply with this Policy or for which we have not separately provided written permission is not a use that we have approved, so you must decide for yourself whether the use is nevertheless lawful.

These guidelines are based on the [Model Trademark Guidelines](http://modeltrademarkguidelines.org/index.php/Home:_Model_Trademark_Guidelines), used under a [Creative Commons Attribution 3.0 Unported license](https://creativecommons.org/licenses/by/3.0/deed.en_US).

OUR COMMITMENT TO OPEN SOURCE PRINCIPLES

We want to encourage and facilitate the use of our trademarks by the community, but do so in a way that still ensures that the trademarks are meaningful as a source and quality indicator for our software and the associated goods and services and continue to embody the high reputation of the software and the community associated with it. This Policy therefore tries to strike the proper balance between: 1) our need to ensure that our trademarks remain reliable indicators of the qualities that they are meant to preserve and 2) our community members' desire to be full participants in the Zcash cryptocurrency.

TRADEMARKS SUBJECT TO GUIDELINES
OUR TRADEMARKS

This Policy covers:

1. Our word trademarks and service marks (the "Word Marks"):

| Mark | Common descriptive name for the goods and services |
|---|---|
| Zcash | The Zcash cryptocurrency; computer software for the use or mining of a cryptocurrency, or the use of a blockchain or distributed ledger |

2. Our logos (the "Logos"):

| Logo | Description |
|---|---|
| ![Zcash trademark logo](/images/zcash-trademark-logo.png) | The Zcash logo |

3. And the unique visual styling of our website and packaging (the "Trade Dress").

This Policy encompasses all trademarks and service marks, whether Word Marks, Logos or Trade Dress, which are collectively referred to as the "Marks." Some Marks may not be registered, but registration does not equal ownership of trademarks. This Policy covers our Marks whether they are registered or not.

## Universal considerations for all uses

Whenever you use one of the Marks, you must always do so in a way that does not mislead anyone, either directly or by omission, about exactly what they are getting and from whom. The law reflects this requirement in two major ways described in more detail below: It prohibits creating a "likelihood of confusion" but allows for "nominative use." For example, you cannot say you are distributing the Zcash software when you're distributing a modified version of it, because people would be confused when they are not getting the same features and functionality they would get if they downloaded the software directly from us. You also cannot use our logo on your website in a way that suggests that your website is an official website or that we endorse your website. You can, though, say you like the Zcash software, that you participate in the Zcash community, that you are providing an unmodified version of the Zcash software, or that you wrote a book describing how to use the Zcash software.

This fundamental requirement, that it is always clear to people what they are getting and from whom, is reflected throughout this Policy. It should also serve as your guide if you are not sure about how you are using the Marks.

In addition:

You may not use the Marks in association with the use or distribution of software if you are also not in compliance with the copyright license for the software.

You may not use or register, in whole or in part, the Marks as part of your own trademark, service mark, domain name, company name, trade name, product name or service name without the express permission of the Company.

Trademark law does not allow your use of names or trademarks that are too similar to ours. You therefore may not use an obvious variation of any of our Marks or any phonetic equivalent, foreign language equivalent, takeoff, or abbreviation for a similar or compatible product or service (including another cryptocurrency, whether or not it is based on or derived or forked from the Zcash software or cryptocurrency). We would consider the following too similar to one of our Marks:

Any mark containing the letters ZCASH.

You agree that you will not acquire any rights in the Marks and that any goodwill generated by your use of the Marks inures solely to our benefit.

USE FOR SOFTWARE

See Universal considerations for all uses, above, which also apply.

USES WE CONSIDER NON-INFRINGING
DISTRIBUTION OF UNMODIFIED SOURCE CODE OR UNMODIFIED EXECUTABLE CODE WE HAVE COMPILED

When you redistribute an unmodified copy of our software, you are not changing the quality or nature of it. Therefore, you may retain the Word Marks and the Logos we have placed on the software to identify your redistribution — whether that redistribution is made by optical media, memory stick or download of unmodified source and executable code. This kind of use only applies if you are redistributing an official distribution from the Zcash Github repository that has not been changed in any way.

DISTRIBUTION OF EXECUTABLE CODE THAT YOU HAVE COMPILED, OR MODIFIED CODE

You may use the Word Marks, but not the Logos, to truthfully describe the origin of the software that you are providing, that is, that the code you are distributing is a modification of our software. You may say, for example, that "this software is derived from the Zcash source code."

Of course, you can place your own trademarks or logos on versions of the software to which you have made substantive modifications, because by modifying the software you have become the origin of that exact version. In that case, you should not use our Logos. Our source code version therefore does not contain our Logo data files.

STATEMENTS ABOUT COMPATIBILITY, INTEROPERABILITY, OR DERIVATION

You may use the Word Marks to truthfully describe the relationship between your software and ours. Our Mark should be used after a verb or preposition that describes the relationship between your software and ours. So you may say, for example, "Bob's software for the Zcash cryptocurrency" but may not say "Bob's Zcash software." Some other examples that may work for you are:

* [Your software, product or service] works with Zcash
* [Your software, product or service] uses Zcash software
* [Your software, product or service] is compatible with Zcash
* [Your software, product or service] is powered by Zcash
* [Your software, product or service] runs on Zcash software
* [Your software, product or service] for use with Zcash software
* [Your software, product or service] for Zcash

You must not claim that your software is compatible with Zcash unless your software complies with the Zcash Protocol Specification, published at https://github.com/zcash/zips/tree/master/protocol.

USE OF TRADEMARKS TO INDICATE ACCEPTANCE OF OR SUPPORT FOR THE ZCASH CRYPTOCURRENCY

You may use the Word Marks and the Logos to indicate that you accept payment in the Zcash cryptocurrency, or that your product or service supports the Zcash cryptocurrency. Our Word Marks should be used in a way that makes the nature of the acceptance of or support for the Zcash cryptocurrency clear. Some examples of acceptable use include:

* We accept payment in Zcash
* [Your product or service] supports Zcash
* Buy or Sell Zcash on [your product or service]

USE OF TRADEMARKS TO SHOW COMMUNITY AFFILIATION

This section discusses the use of our Marks for software such an application themes, skins and personas. The use of our Marks on websites is discussed below.

You may use the Word Marks and the Logos in themes, personas, or skins for applications to show your support for Zcash, provided that the use is non-commercial and the use is clearly decorative, as contrasted with a use that appears to be the branding for a website or application.

USES WE CONSIDER INFRINGING WITHOUT SEEKING FURTHER PERMISSION FROM US

We will likely consider using the Marks in a software distribution that combines our software with any other software program an infringement of our Marks. We would consider your software "combined" with ours if you create a single executable for both software programs, as well as if by installing our software it automatically installs yours. We would not consider your software "combined" with ours if it is on the same media but requires separate, independent action to install it.

USE FOR NON-SOFTWARE GOODS AND SERVICES

See Universal considerations for all uses, above, which also apply.

USES WE CONSIDER NON-INFRINGING
WEBSITES

You may use the Word Marks and Logos, but not the Trade Dress, on your webpage to show your support for Zcash as long as:

* The website has branding that is easily distinguished from the Zcash Trade Dress;
* You own branding or naming is more prominent than any Project Marks;
* The Logos hyperlink to the Zcash website;
* The site does not mislead customers into thinking that either your website, service, or product is our website, service, or product; and
* The site clearly states that you are not affiliated with or endorsed by the Zcash Foundation.

PUBLICATIONS AND PRESENTATIONS

You can use the Word Marks in book and article titles, and the Logo in illustrations within the document, as long as the use does not suggest that we have published, endorse, or agree with your work.

USES FOR WHICH WE ARE GRANTING A LICENSE

USER GROUPS AND MEETUPS

You can use the Word Marks as part of your user group or meetup name provided that:

* The main focus of the group or meetup is the Zcash software and/or cryptocurrency;
* Any software or services the group or meetup provides are without cost;
* The group or meetup does not make a profit;
* Any charge to attend meetings are to cover the cost of the venue, food, and drink only.

Note that the Universal considerations for all uses, above, still apply, specifically, that you may not use or register the Marks as part of your own trademark, service mark, domain name, company name, trade name, product name or service name.

PROMOTIONAL GOODS

"Promotional goods" are non-software goods that use the Marks and that are intended to advertise Zcash, promote Zcash, or show membership in the Zcash community.

You may make promotional goods for free giveaway.

USES WE CONSIDER INFRINGING WITHOUT SEEKING FURTHER PERMISSION

We will likely consider using the Marks as part of a domain name or subdomain an infringement of our Marks. We would likely consider using the Marks on promotional goods for sale an infringement of our Marks.

GENERAL INFORMATION

TRADEMARK MARKING AND LEGENDS

The first or most prominent mention of a Mark on a webpage, document, packaging, or documentation should be accompanied by a symbol indicating whether the mark is a registered trademark ("®") or an unregistered trademark ("TM"). See our Trademark List for the correct symbol to use.

Also, if you are using our Marks in a way described in the section "Uses for which we are granting a license," please put following notice at the foot of the page where you have used the Mark (or, if in a book, on the credits page), on any packaging or labeling, and on advertising or marketing materials: "Zcash is a trademark of the Zcash Foundation. Used with permission from the Zcash Foundation."

WHAT TO DO WHEN YOU SEE ABUSE

If you are aware of any confusing use or misuse of the Marks in any way, we would appreciate you bringing this to our attention. Please contact us as described below so that we can investigate it further.

## Where to get further information

If you have any questions about this Policy, would like to speak with us about the use of our Marks in ways not described in the Policy, or see any abuse of our Marks, please email contact@zfnd.org.

GENERAL CONSIDERATIONS ABOUT TRADEMARKS AND THEIR USE

WHAT TRADEMARK LAW IS ABOUT

WHAT IS A TRADEMARK?

A trademark is a word, phrase, symbol or design, or a combination of words, phrases, symbols or designs, that identifies and distinguishes the source of the goods of one party from those of others. A service mark is the same as a trademark, except that it identifies and distinguishes the source of a service rather than a product. "Trade dress" or "get up" refers to the look and feel of the packaging, which in this context can include the layout, colors, images, and design choices in a web page. Throughout this Policy, the terms "trademark" and "mark" refer to both trademarks, service marks and trade dress.

However, the use of a word is "not as a trademark" when it is used functionally as part of the software program, for example, in a file, folder, directory, or path name. Use in this way is not a trademark infringement.

WHAT IS "LIKELIHOOD OF CONFUSION"?

There is trademark infringement if your use of a trademark has created a "likelihood of confusion." This means using a trademark in a way that will likely confuse or deceive the relevant consuming public about the source of a product or service using the mark in question. For example, if the "Foo" software extension removes all double spaces after periods, but someone else later creates "Foo" software that adds a third space after periods, consumers would be confused between the two and the newcomer will likely be a trademark infringer. As another example, if a company makes "Foobar" software and a third party offers training called "Foobar Certification,"" a person is likely to believe, wrongly, that the certification is being offered by the makers of Foobar software. The third party has likely misled consumers about the source of its training and is a trademark infringer.

WHAT IS "NOMINATIVE" USE?

So-called "nominative use" (or "nominative fair use"), which is the name of the doctrine under U.S. trademark law, allows the use of another’s trademark where it is necessary for understanding. Other countries' trademark laws also have similar provisions. For example, a car repair shop that specializes in a particular brand of automobile, VW for example, must be allowed to say that they repair VW cars. Here is what you should consider when deciding whether your use of a trademark is a nominative fair use:

* Whether you can identify the product or service in question without using the trademark;
* Whether you are avoiding a likelihood of confusion in the way that you have used the trademark; and
* Whether you have used only as much as is necessary to identify the product or service.

With our "Foobar Certification" example above, the person offering the certification would be allowed to say, under the nominative fair use doctrine, that she is offering "Maude's Certification for Foobar software."

PROPER TRADEMARK USE

These rules hold true for all trademarks, not just ours, so you should follow them for our Marks as well as anyone else’s.

USE OF TRADEMARKS IN TEXT

Always distinguish trademarks from surrounding text with at least initial capital letters or in all capital letters.

* Unacceptable: zcash
* Acceptable: Zcash, ZCASH

POLICY UPDATES

The Zcash Foundation reserves the right to modify this Trademark Policy at any time. You should review this Trademark Policy from time to time so that you will be aware of any updates. Any updates will apply as soon as they are posted on this page.
